{
  description = "Wyatt's configuration";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixpkgs-unstable";
    nix-darwin.url = "github:LnL7/nix-darwin";
    nix-darwin.inputs.nixpkgs.follows = "nixpkgs";
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    mac-app-util.url = "github:hraban/mac-app-util";
  };

  outputs = inputs@{ self, nix-darwin, home-manager, nixpkgs, mac-app-util }:
    {
      # Build darwin flake using:
      # $ darwin-rebuild build --flake .#sephiroth
      darwinConfigurations."sephiroth" = nix-darwin.lib.darwinSystem {
        modules = [
          ./hosts/sephiroth/configuration.nix

          mac-app-util.darwinModules.default

          home-manager.darwinModules.home-manager
          {
            home-manager.useGlobalPkgs = true;
            home-manager.useUserPackages = true;
            home-manager.verbose = true;
            home-manager.users.wyatt.imports = [ ./hosts/sephiroth/home.nix mac-app-util.homeManagerModules.default ];
          }
        ];
      };

      # Expose the package set, including overlays, for convenience.
      darwinPackages = self.darwinConfigurations."sephiroth".pkgs;
    };
}
